pointed_msg_expansion

Function pointed_msg_expansion 

fn pointed_msg_expansion(pointers: Vec<PointedMessage>) -> Vec<PointedMessage>
Expand Vec<PointedMessage>. That is; for each PointedMessage, follow its location’s link until such link is no longer available, adding a newly created PointedMessage to the returned Vec for each linked location.