pub(crate) fn set_predicate(predicate: FilterRule)Expand description
Configure the error reporter to only show errors that match this FilterRule.
pub(crate) fn set_predicate(predicate: FilterRule)Configure the error reporter to only show errors that match this FilterRule.