Errors

Struct Errors 

pub struct Errors<'a> {
    pub(crate) loaded_mods_labels: Vec<String>,
    pub(crate) loaded_dlcs_labels: Vec<String>,
    pub(crate) cache: Cache,
    pub(crate) filter: ReportFilter,
    pub(crate) styles: OutputStyle,
    pub(crate) suppress: TigerHashMap<SuppressionKey<'a>, Vec<Vec<SuppressionLocation>>>,
    ignore: TigerHashMap<&'a Path, Vec<IgnoreEntry>>,
    storage: TigerHashMap<LogReportMetadata, TigerHashSet<LogReportPointers>>,
}

Fields

loaded_mods_labels: Vec<String>

Extra loaded mods’ error tags.

loaded_dlcs_labels: Vec<String>

Loaded DLCs’ error tags.

cache: Cachefilter: ReportFilter

Determines whether a report should be printed.

styles: OutputStyle

Output color and style configuration.

suppress: TigerHashMap<SuppressionKey<'a>, Vec<Vec<SuppressionLocation>>>ignore: TigerHashMap<&'a Path, Vec<IgnoreEntry>>storage: TigerHashMap<LogReportMetadata, TigerHashSet<LogReportPointers>>

All reports that passed the checks, stored here to be sorted before being emitted all at once. The “abbreviated” reports don’t participate in this. They are still emitted immediately. It’s a HashSet because duplicate reports are fairly common due to macro expansion and other revalidations.

Implementations

Source

impl Errors<'_>

fn should_suppress( &self, report: &LogReportMetadata, pointers: &LogReportPointers, ) -> bool

fn should_ignore( &self, report: &LogReportMetadata, pointers: &LogReportPointers, ) -> bool

fn push_report( &mut self, report: LogReportMetadata, pointers: LogReportPointers, )

Perform some checks to see whether the report should actually be logged. If yes, it will add it to the storage.

pub fn flatten_reports( &self, consolidate: bool, ) -> Vec<(&LogReportMetadata, Cow<'_, LogReportPointers>, usize)>

Extract the stored reports, sort them, and return them as a vector.

pub fn emit_reports<O: Write + Send>( &mut self, output: &mut O, json: bool, consolidate: bool, summary: bool, ) -> bool

Print the stored reports. Set json if they should be printed as a JSON array. Otherwise they are printed in the default output format.

Note that the default output format is not stable across versions. It is meant for human readability and occasionally gets changed to improve that.

Reports matched by #tiger-ignore directives will not be printed.

Returns true iff any reports were printed.

pub fn store_source_file(&mut self, fullpath: PathBuf, source: &'static str)

pub fn get_mut() -> MutexGuard<'static, Errors<'static>>

Get a mutable lock on the global ERRORS struct.

Panics

May panic when the mutex has been poisoned by another thread.

pub fn get() -> MutexGuard<'static, Errors<'static>>

Like Errors::get_mut but intended for read-only access.

Currently there is no difference, but if the locking mechanism changes there may be a difference.

Panics

May panic when the mutex has been poisoned by another thread.